@@ -1,7 +1,12 @@
 ''' Data types for schemdraw '''
 
-from __future__ import annotations
-from typing import Literal, Union, Sequence, Optional
+import sys
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+from typing import Union, Tuple, Sequence, Optional
 from collections import namedtuple
 from enum import Enum, unique
 
@@ -17,11 +22,20 @@ Direction = Union[Literal['up', 'down', 'left', 'right',
                           'u', 'd', 'l', 'r'], int]
 Halign = Literal['center', 'left', 'right']
 Valign = Literal['center', 'top', 'bottom']
-Align = tuple[Optional[Halign], Optional[Valign]]
+Align = Tuple[Optional[Halign], Optional[Valign]]
 Arcdirection = Literal['cw', 'ccw']
-Side = Literal['top', 'bot', 'lft', 'rgt', 'bottom', 'left', 'right']
+Side = Literal['top', 'bot', 'lft', 'rgt', 'bottom', 'left', 'right', 'L', 'R', 'T', 'B']
 LabelLoc = Union[Side, str]
 XY = Union[Sequence[float], Point]
+RotationMode = Literal['anchor', 'default']
+TextMode = Literal['path', 'text']
+
+BilateralDirection = Literal['in', 'out']
+EndRef = Literal['start', 'end']
+ActionType = Optional[Literal['open', 'close']]
+HeaderStyle = Literal['round', 'square', 'screw']
+HeaderNumbering = Literal['lr', 'ud', 'ccw']
+
 
 Backends = Literal['svg', 'matplotlib']
 
